@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.09';
+our $VERSION = '0.0901';
 
 use Moo;
 use strictures 2;
@@ -220,7 +220,7 @@ sub process {
                 $analysis .= sprintf "\t%d\t%d\t%s %s\n", $j, $phrase->{$p}, $num, $text;
 
                 # Save the number of times the phrase is repeated
-                $self->notes->{$track_channel}{$num} = $phrase->{$p};
+                $self->notes->{$track_channel}{$num} += $phrase->{$p};
             }
 
             $analysis .= $self->_gestalt_analysis( \@events )
@@ -442,7 +442,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.09
+version 0.0901
 
 =head1 SYNOPSIS
 
